==> webStore_2.8.2_estable.zip: comunes/procesos_seccion/global.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 16/Noviembre/2015
	// Versión 1.0 Este proceso se ejecuta antes de la carga de la sección y se usa para propósitos generales. Por ahora determinará el tipo de ficha a utilizar
	//---------------------------------------------------------------------------------------------------------
	// 17/Noviembre/2015
	// Versión 1.1 Añadimos la opción de orden de escaparates
	//---------------------------------------------------------------------------------------------------------

	

    $recargar_web = $recargar_web | false;
	$tipo_ficha_producto = Getter::get('tipo_ficha_producto');
	if ($tipo_ficha_producto !== NULL){
		if ($tipo_ficha_producto == ''){
			//Hay que borrar la cookie y la sesión
			cleanSessionVariable('tipo_ficha_producto');
			borrarCookie('tipo_ficha_producto');
		}else{
			//Hay que guardarlo en las sesiones y en las cookies:
			Sesion::set('tipo_ficha_producto', $tipo_ficha_producto);
			crearCookie('tipo_ficha_producto', $tipo_ficha_producto);
		}
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}

	$orden_lista_productos = Getter::get('orden_lista_productos');
	if ($orden_lista_productos !== NULL){
		if ($orden_lista_productos == ''){
			//Hay que borrar la cookie y la sesión
			cleanSessionVariable('orden_lista_productos');
			borrarCookie('orden_lista_productos');
		}else{
			//Hay que guardarlo en las sesiones y en las cookies:
			Sesion::set('orden_lista_productos', $orden_lista_productos);
			crearCookie('orden_lista_productos', $orden_lista_productos);
		}
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}

	$elementos_por_pagina = Getter::get('elementos_por_pagina');
	if ($elementos_por_pagina !== NULL){
		if ($elementos_por_pagina == ''){
			//Hay que borrar la cookie y la sesión
			cleanSessionVariable('elementos_por_pagina');
			borrarCookie('elementos_por_pagina');
		}else{
			//Hay que guardarlo en las sesiones y en las cookies:
			Sesion::set('elementos_por_pagina', $elementos_por_pagina);
			crearCookie('elementos_por_pagina', $elementos_por_pagina);
		}
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}else{
		$elementos_por_pagina = Sesion::getCookieValue('elementos_por_pagina');
		if ($elementos_por_pagina == NULL){
			$elementos_por_pagina = Sesion::get('elementos_por_pagina');
		}
	}
	//Si hay elementos por página, sobre escribimos el valor de configuración
	Shop::$configuracion->elementos_por_pagina = ($elementos_por_pagina != NULL) ? $elementos_por_pagina : Shop::$configuracion->elementos_por_pagina;
?>

==> webStore_2.8.9.003_estable.zip: comunes/procesos_seccion/global.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 16/Noviembre/2015
	// Versión 1.0 Este proceso se ejecuta antes de la carga de la sección y se usa para propósitos generales. Por ahora determinará el tipo de ficha a utilizar
	//---------------------------------------------------------------------------------------------------------
	// 17/Noviembre/2015
	// Versión 1.1 Añadimos la opción de orden de escaparates
	//---------------------------------------------------------------------------------------------------------

	

    $recargar_web = $recargar_web | false;
	$tipo_ficha_producto = Getter::get('tipo_ficha_producto');
	if ($tipo_ficha_producto !== NULL){
		if ($tipo_ficha_producto == ''){
			//Hay que borrar la cookie y la sesión
			cleanSessionVariable('tipo_ficha_producto');
			borrarCookie('tipo_ficha_producto');
		}else{
			//Hay que guardarlo en las sesiones y en las cookies:
			Sesion::set('tipo_ficha_producto', $tipo_ficha_producto);
			crearCookie('tipo_ficha_producto', $tipo_ficha_producto);
		}
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}

	$orden_lista_productos = Getter::get('orden_lista_productos');
	if ($orden_lista_productos !== NULL){
		if ($orden_lista_productos == ''){
			//Hay que borrar la cookie y la sesión
			cleanSessionVariable('orden_lista_productos');
			borrarCookie('orden_lista_productos');
		}else{
			//Hay que guardarlo en las sesiones y en las cookies:
			Sesion::set('orden_lista_productos', $orden_lista_productos);
			crearCookie('orden_lista_productos', $orden_lista_productos);
		}
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}

	$elementos_por_pagina = Getter::get('elementos_por_pagina');
	if ($elementos_por_pagina !== NULL){
		if ($elementos_por_pagina == ''){
			//Hay que borrar la cookie y la sesión
			cleanSessionVariable('elementos_por_pagina');
			borrarCookie('elementos_por_pagina');
		}else{
			//Hay que guardarlo en las sesiones y en las cookies:
			Sesion::set('elementos_por_pagina', $elementos_por_pagina);
			crearCookie('elementos_por_pagina', $elementos_por_pagina);
		}
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}else{
		$elementos_por_pagina = Sesion::getCookieValue('elementos_por_pagina');
		if ($elementos_por_pagina == NULL){
			$elementos_por_pagina = Sesion::get('elementos_por_pagina');
		}
	}
	//Si hay elementos por página, sobre escribimos el valor de configuración
	Shop::$configuracion->elementos_por_pagina = ($elementos_por_pagina != NULL) ? $elementos_por_pagina : Shop::$configuracion->elementos_por_pagina;
?>
